@@ -76,7 +76,7 @@ class Domains extends ApiCommand implements ResourceEntity
 			$query_fields = [];
 			$result_stmt = Database::prepare("
 				SELECT
-				`d`.*, `c`.`loginname`, `c`.`deactivated`, `c`.`name`, `c`.`firstname`, `c`.`company`, `c`.`standardsubdomain`, `c`.`adminid` as customeradmin,
+				`d`.*, `c`.`loginname`, `c`.`deactivated` as `customer_deactivated`, `c`.`name`, `c`.`firstname`, `c`.`company`, `c`.`standardsubdomain`, `c`.`adminid` as customeradmin,
 				`ad`.`id` AS `aliasdomainid`, `ad`.`domain` AS `aliasdomain`
 				FROM `" . TABLE_PANEL_DOMAINS . "` `d`
 				LEFT JOIN `" . TABLE_PANEL_CUSTOMERS . "` `c` USING(`customerid`)
@@ -110,7 +110,7 @@ class Domains extends ApiCommand implements ResourceEntity
 	 *
 	 * @param number $domain_id
 	 * @param bool $ssl_only
-	 *            optional, return only ssl enabled ip's, default false
+	 *            optional, return only ssl enabled ips, default false
 	 * @return array
 	 */
 	private function getIpsForDomain($domain_id = 0, $ssl_only = false)
@@ -190,9 +190,6 @@ class Domains extends ApiCommand implements ResourceEntity
 	 *            optional, whether to create an exclusive web-logfile for this domain, default 0 (false)
 	 * @param int $alias
 	 *            optional, domain-id of a domain that the new domain should be an alias of, default 0 (none)
-	 * @param int $issubof
-	 *            optional, domain-id of a domain this domain is a subdomain of (required for webserver-cronjob to
-	 *            generate the correct order), default 0 (none)
 	 * @param string $registration_date
 	 *            optional, date of domain registration in form of YYYY-MM-DD, default empty (none)
 	 * @param string $termination_date
@@ -210,7 +207,7 @@ class Domains extends ApiCommand implements ResourceEntity
 	 * @param string $ssl_specialsettings
 	 *            optional, custom webserver vhost-content which is added to the generated ssl-vhost, default empty
 	 * @param bool $include_specialsettings
-	 *            optional, whether or not to include non-ssl specialsettings in the generated ssl-vhost, default false
+	 *            optional, whether to include non-ssl specialsettings in the generated ssl-vhost, default false
 	 * @param bool $notryfiles
 	 *            optional, [nginx only] do not generate the default try-files directive, default 0 (false)
 	 * @param bool $writeaccesslog
@@ -219,7 +216,7 @@ class Domains extends ApiCommand implements ResourceEntity
 	 *            optional, Enable writing an error-log file for this domain, default 1 (true)
 	 * @param string $documentroot
 	 *            optional, specify homedir of domain by specifying a directory (relative to customer-docroot), be
-	 *            aware, if path starts with / it it considered a full path, not relative to customer-docroot. Also
+	 *            aware, if path starts with / it is considered a full path, not relative to customer-docroot. Also
 	 *            specifying a URL is possible here (redirect), default empty (autogenerated)
 	 * @param bool $phpenabled
 	 *            optional, whether php is enabled for this domain, default 0 (false)
@@ -244,7 +241,7 @@ class Domains extends ApiCommand implements ResourceEntity
 	 *            optional, do NOT set the systems default ssl ip addresses if none are given via $ssl_ipandport
 	 *            parameter
 	 * @param bool $sslenabled
-	 *            optional, whether or not SSL is enabled for this domain, regardless of the assigned ssl-ips, default
+	 *            optional, whether SSL is enabled for this domain, regardless of the assigned ssl-ips, default
 	 *            1 (true)
 	 * @param bool $http2
 	 *            optional, whether to enable http/2 for this domain (requires to be enabled in the settings), default
@@ -252,9 +249,9 @@ class Domains extends ApiCommand implements ResourceEntity
 	 * @param int $hsts_maxage
 	 *            optional max-age value for HSTS header
 	 * @param bool $hsts_sub
-	 *            optional whether or not to add subdomains to the HSTS header
+	 *            optional whether to add subdomains to the HSTS header
 	 * @param bool $hsts_preload
-	 *            optional whether or not to preload HSTS header value
+	 *            optional whether to preload HSTS header value
 	 * @param bool $ocsp_stapling
 	 *            optional whether to enable ocsp-stapling for this domain. default 0 (false), requires SSL
 	 * @param bool $honorcipherorder
@@ -263,7 +260,7 @@ class Domains extends ApiCommand implements ResourceEntity
 	 *            optional whether to enable or disable TLS sessiontickets (RFC 5077) for this domain. default 1
 	 *            (true), requires SSL
 	 * @param bool $override_tls
-	 *            optional whether or not to override system-tls settings like protocol, ssl-ciphers and if applicable
+	 *            optional whether to override system-tls settings like protocol, ssl-ciphers and if applicable
 	 *            tls-1.3 ciphers, requires change_serversettings flag for the admin, default false
 	 * @param array $ssl_protocols
 	 *            optional list of allowed/used ssl/tls protocols, see system.ssl_protocols setting, only used/required
@@ -298,7 +295,6 @@ class Domains extends ApiCommand implements ResourceEntity
 				$serveraliasoption = $this->getParam('selectserveralias', true, Settings::Get('system.domaindefaultalias'));
 				$speciallogfile = $this->getBoolParam('speciallogfile', true, 0);
 				$aliasdomain = intval($this->getParam('alias', true, 0));
-				$issubof = $this->getParam('issubof', true, 0);
 				$registration_date = $this->getParam('registration_date', true, '');
 				$termination_date = $this->getParam('termination_date', true, '');
 				$caneditdomain = $this->getBoolParam('caneditdomain', true, 0);
@@ -320,9 +316,9 @@ class Domains extends ApiCommand implements ResourceEntity
 				$mod_fcgid_maxrequests = $this->getParam('mod_fcgid_maxrequests', true, -1);
 				$ssl_redirect = $this->getBoolParam('ssl_redirect', true, 0);
 				$letsencrypt = $this->getBoolParam('letsencrypt', true, 0);
+				$sslenabled = $this->getBoolParam('sslenabled', true, 1);
 				$dont_use_default_ssl_ipandport_if_empty = $this->getBoolParam('dont_use_default_ssl_ipandport_if_empty', true, 0);
 				$p_ssl_ipandports = $this->getParam('ssl_ipandport', true, $dont_use_default_ssl_ipandport_if_empty ? [] : explode(',', Settings::Get('system.defaultsslip')));
-				$sslenabled = $this->getBoolParam('sslenabled', true, 1);
 				$http2 = $this->getBoolParam('http2', true, 0);
 				$hsts_maxage = $this->getParam('hsts_maxage', true, 0);
 				$hsts_sub = $this->getBoolParam('hsts_sub', true, 0);
@@ -353,6 +349,8 @@ class Domains extends ApiCommand implements ResourceEntity
 
 				if (substr($p_domain, 0, 4) == 'xn--') {
 					Response::standardError('domain_nopunycode', '', true);
+				} elseif (Validate::validate_ip2($p_domain, true, '', true, true)) {
+					Response::standardError('domain_noipaddress', '', true);
 				}
 
 				$idna_convert = new IdnaWrapper();
@@ -548,6 +546,10 @@ class Domains extends ApiCommand implements ResourceEntity
 						$ssl_specialsettings = Validate::validate(str_replace("\r\n", "\n", $ssl_specialsettings), 'ssl_specialsettings', '/^[^\0]*$/', '', [], true);
 					}
 				}
+				if (Settings::Get('system.use_ssl') == "1" && $sslenabled == 1 && empty($ssl_ipandports)) {
+					// enabled ssl for the domain but no ssl ip/port is selected
+					Response::standardError('nosslippportgiven', '', true);
+				}
 				if (Settings::Get('system.use_ssl') == "0" || empty($ssl_ipandports)) {
 					$ssl_redirect = 0;
 					$letsencrypt = 0;
@@ -665,10 +667,6 @@ class Domains extends ApiCommand implements ResourceEntity
 					$serveraliasoption = '0';
 				}
 
-				if ($issubof <= 0) {
-					$issubof = '0';
-				}
-
 				$idna_convert = new IdnaWrapper();
 				if ($domain == '') {
 					Response::standardError([
@@ -723,7 +721,6 @@ class Domains extends ApiCommand implements ResourceEntity
 						'phpsettingid' => $phpsettingid,
 						'mod_fcgid_starter' => $mod_fcgid_starter,
 						'mod_fcgid_maxrequests' => $mod_fcgid_maxrequests,
-						'ismainbutsubto' => $issubof,
 						'letsencrypt' => $letsencrypt,
 						'http2' => $http2,
 						'hsts' => $hsts_maxage,
@@ -777,7 +774,6 @@ class Domains extends ApiCommand implements ResourceEntity
 						`phpsettingid` = :phpsettingid,
 						`mod_fcgid_starter` = :mod_fcgid_starter,
 						`mod_fcgid_maxrequests` = :mod_fcgid_maxrequests,
-						`ismainbutsubto` = :ismainbutsubto,
 						`letsencrypt` = :letsencrypt,
 						`http2` = :http2,
 						`hsts` = :hsts,
@@ -1069,9 +1065,6 @@ class Domains extends ApiCommand implements ResourceEntity
 	 *            default 0 (false)
 	 * @param int $alias
 	 *            optional, domain-id of a domain that the new domain should be an alias of, default 0 (none)
-	 * @param int $issubof
-	 *            optional, domain-id of a domain this domain is a subdomain of (required for webserver-cronjob to
-	 *            generate the correct order), default 0 (none)
 	 * @param string $registration_date
 	 *            optional, date of domain registration in form of YYYY-MM-DD, default empty (none)
 	 * @param string $termination_date
@@ -1089,7 +1082,7 @@ class Domains extends ApiCommand implements ResourceEntity
 	 * @param string $ssl_specialsettings
 	 *            optional, custom webserver vhost-content which is added to the generated ssl-vhost, default empty
 	 * @param bool $include_specialsettings
-	 *            optional, whether or not to include non-ssl specialsettings in the generated ssl-vhost, default false
+	 *            optional, whether to include non-ssl specialsettings in the generated ssl-vhost, default false
 	 * @param bool $specialsettingsforsubdomains
 	 *            optional, whether to apply specialsettings to all subdomains of this domain, default is read from
 	 *            setting system.apply_specialsettings_default
@@ -1101,7 +1094,7 @@ class Domains extends ApiCommand implements ResourceEntity
 	 *            optional, Enable writing an error-log file for this domain, default 1 (true)
 	 * @param string $documentroot
 	 *            optional, specify homedir of domain by specifying a directory (relative to customer-docroot), be
-	 *            aware, if path starts with / it it considered a full path, not relative to customer-docroot. Also
+	 *            aware, if path starts with / it is considered a full path, not relative to customer-docroot. Also
 	 *            specifying a URL is possible here (redirect), default empty (autogenerated)
 	 * @param bool $phpenabled
 	 *            optional, whether php is enabled for this domain, default 0 (false)
@@ -1130,7 +1123,7 @@ class Domains extends ApiCommand implements ResourceEntity
 	 *            optional, if set to true and no $ssl_ipandport value is given, the ip's get removed, otherwise, the
 	 *            currently set value is used, default false
 	 * @param bool $sslenabled
-	 *            optional, whether or not SSL is enabled for this domain, regardless of the assigned ssl-ips, default
+	 *            optional, whether SSL is enabled for this domain, regardless of the assigned ssl-ips, default
 	 *            1 (true)
 	 * @param bool $http2
 	 *            optional, whether to enable http/2 for this domain (requires to be enabled in the settings), default
@@ -1138,9 +1131,9 @@ class Domains extends ApiCommand implements ResourceEntity
 	 * @param int $hsts_maxage
 	 *            optional max-age value for HSTS header
 	 * @param bool $hsts_sub
-	 *            optional whether or not to add subdomains to the HSTS header
+	 *            optional whether to add subdomains to the HSTS header
 	 * @param bool $hsts_preload
-	 *            optional whether or not to preload HSTS header value
+	 *            optional whether to preload HSTS header value
 	 * @param bool $ocsp_stapling
 	 *            optional whether to enable ocsp-stapling for this domain. default 0 (false), requires SSL
 	 * @param bool $honorcipherorder
@@ -1150,6 +1143,8 @@ class Domains extends ApiCommand implements ResourceEntity
 	 *            (true), requires SSL
 	 * @param string $description
 	 *            optional custom description (currently not used/shown in the frontend), default empty
+	 * @param bool $deactivated
+	 *            optional, if 1 (true) the domain can be deactivated/suspended
 	 *
 	 * @access admin
 	 * @return string json-encoded array
@@ -1191,7 +1186,6 @@ class Domains extends ApiCommand implements ResourceEntity
 			$speciallogfile = $this->getBoolParam('speciallogfile', true, $result['speciallogfile']);
 			$speciallogverified = $this->getBoolParam('speciallogverified', true, 0);
 			$aliasdomain = intval($this->getParam('alias', true, $result['aliasdomain']));
-			$issubof = $this->getParam('issubof', true, $result['ismainbutsubto']);
 			$registration_date = $this->getParam('registration_date', true, $result['registration_date']);
 			$termination_date = $this->getParam('termination_date', true, $result['termination_date']);
 			$caneditdomain = $this->getBoolParam('caneditdomain', true, $result['caneditdomain']);
@@ -1219,7 +1213,7 @@ class Domains extends ApiCommand implements ResourceEntity
 			$p_ssl_ipandports = $this->getParam('ssl_ipandport', true, $remove_ssl_ipandport ? [
 				-1
 			] : null);
-			$sslenabled = $this->getBoolParam('sslenabled', true, $result['ssl_enabled']);
+			$sslenabled = $remove_ssl_ipandport ? false : $this->getBoolParam('sslenabled', true, $result['ssl_enabled']);
 			$http2 = $this->getBoolParam('http2', true, $result['http2']);
 			$hsts_maxage = $this->getParam('hsts_maxage', true, $result['hsts']);
 			$hsts_sub = $this->getBoolParam('hsts_sub', true, $result['hsts_sub']);
@@ -1246,6 +1240,7 @@ class Domains extends ApiCommand implements ResourceEntity
 				$tlsv13_cipher_list = $result['tlsv13_cipher_list'];
 			}
 			$description = $this->getParam('description', true, $result['description']);
+			$deactivated = $this->getBoolParam('deactivated', true, $result['deactivated']);
 
 			// count subdomain usage of source-domain
 			$subdomains_stmt = Database::prepare("
@@ -1528,6 +1523,10 @@ class Domains extends ApiCommand implements ResourceEntity
 			if ($remove_ssl_ipandport || (!empty($p_ssl_ipandports) && $p_ssl_ipandports[0] == -1)) {
 				$ssl_ipandports = [];
 			}
+			if (Settings::Get('system.use_ssl') == "1" && $sslenabled && empty($ssl_ipandports)) {
+				// enabled ssl for the domain but no ssl ip/port is selected
+				Response::standardError('nosslippportgiven', '', true);
+			}
 			if (Settings::Get('system.use_ssl') == "0" || empty($ssl_ipandports)) {
 				$ssl_redirect = 0;
 				$letsencrypt = 0;
@@ -1564,7 +1563,7 @@ class Domains extends ApiCommand implements ResourceEntity
 			}
 
 			// Temporarily deactivate ssl_redirect until Let's Encrypt certificate was generated
-			if ($ssl_redirect > 0 && $letsencrypt == 1 && $result['letsencrypt'] != $letsencrypt) {
+			if (($result['letsencrypt'] != $letsencrypt || $result['ssl_redirect'] != $ssl_redirect) && $ssl_redirect > 0 && $letsencrypt == 1) {
 				$ssl_redirect = 2;
 			}
 
@@ -1640,10 +1639,6 @@ class Domains extends ApiCommand implements ResourceEntity
 				Response::standardError('domainisaliasorothercustomer', '', true);
 			}
 
-			if ($issubof <= 0) {
-				$issubof = '0';
-			}
-
 			if ($serveraliasoption != '1' && $serveraliasoption != '2') {
 				$serveraliasoption = '0';
 			}
@@ -1657,6 +1652,7 @@ class Domains extends ApiCommand implements ResourceEntity
 				|| $iswildcarddomain != $result['iswildcarddomain']
 				|| $phpenabled != $result['phpenabled']
 				|| $openbasedir != $result['openbasedir']
+				|| $openbasedir_path != $result['openbasedir_path']
 				|| $phpsettingid != $result['phpsettingid']
 				|| $mod_fcgid_starter != $result['mod_fcgid_starter']
 				|| $mod_fcgid_maxrequests != $result['mod_fcgid_maxrequests']
@@ -1666,7 +1662,6 @@ class Domains extends ApiCommand implements ResourceEntity
 				|| $writeaccesslog != $result['writeaccesslog']
 				|| $writeerrorlog != $result['writeerrorlog']
 				|| $aliasdomain != $result['aliasdomain']
-				|| $issubof != $result['ismainbutsubto']
 				|| $email_only != $result['email_only']
 				|| ($speciallogfile != $result['speciallogfile'] && $speciallogverified == '1')
 				|| $letsencrypt != $result['letsencrypt']
@@ -1675,6 +1670,7 @@ class Domains extends ApiCommand implements ResourceEntity
 				|| $hsts_sub != $result['hsts_sub']
 				|| $hsts_preload != $result['hsts_preload']
 				|| $ocsp_stapling != $result['ocsp_stapling']
+				|| $sslenabled != $result['ssl_enabled']
 			) {
 				Cronjob::inserttask(TaskId::REBUILD_VHOST);
 			}
@@ -1823,7 +1819,7 @@ class Domains extends ApiCommand implements ResourceEntity
 			$update_data['wwwserveralias'] = $wwwserveralias;
 			$update_data['iswildcarddomain'] = $iswildcarddomain;
 			$update_data['phpenabled'] = $phpenabled;
-			$update_data['openbasedir'] = $openbasedir;;
+			$update_data['openbasedir'] = $openbasedir;
 			$update_data['openbasedir_path'] = $openbasedir_path;
 			$update_data['speciallogfile'] = $speciallogfile;
 			$update_data['phpsettingid'] = $phpsettingid;
@@ -1837,7 +1833,6 @@ class Domains extends ApiCommand implements ResourceEntity
 			$update_data['writeerrorlog'] = $writeerrorlog;
 			$update_data['registration_date'] = $registration_date;
 			$update_data['termination_date'] = $termination_date;
-			$update_data['ismainbutsubto'] = $issubof;
 			$update_data['letsencrypt'] = $letsencrypt;
 			$update_data['http2'] = $http2;
 			$update_data['hsts'] = $hsts_maxage;
@@ -1852,6 +1847,7 @@ class Domains extends ApiCommand implements ResourceEntity
 			$update_data['honorcipherorder'] = $honorcipherorder;
 			$update_data['sessiontickets'] = $sessiontickets;
 			$update_data['description'] = $description;
+			$update_data['deactivated'] = $deactivated;
 			$update_data['id'] = $id;
 
 			$update_stmt = Database::prepare("
@@ -1885,7 +1881,6 @@ class Domains extends ApiCommand implements ResourceEntity
 				`writeerrorlog` = :writeerrorlog,
 				`registration_date` = :registration_date,
 				`termination_date` = :termination_date,
-				`ismainbutsubto` = :ismainbutsubto,
 				`letsencrypt` = :letsencrypt,
 				`http2` = :http2,
 				`hsts` = :hsts,
@@ -1899,11 +1894,36 @@ class Domains extends ApiCommand implements ResourceEntity
 				`ssl_enabled` = :sslenabled,
 				`ssl_honorcipherorder` = :honorcipherorder,
 				`ssl_sessiontickets` = :sessiontickets,
-				`description` = :description
+				`description` = :description,
+				`deactivated` = :deactivated
 				WHERE `id` = :id
 			");
 			Database::pexecute($update_stmt, $update_data, true, true);
 
+			// activate/deactivate domain-based services
+			if ($deactivated != $result['deactivated']) {
+				// deactivate email accounts
+				$yesno = ($deactivated ? 'N' : 'Y');
+				$pop3 = ($deactivated ? '0' : (int)$customer['pop3']);
+				$imap = ($deactivated ? '0' : (int)$customer['imap']);
+
+				$upd_stmt = Database::prepare("
+					UPDATE `" . TABLE_MAIL_USERS . "`
+					SET `postfix`= :yesno, `pop3` = :pop3, `imap` = :imap
+					WHERE `customerid` = :customerid AND `domainid` = :domainid
+				");
+				Database::pexecute($upd_stmt, [
+					'yesno' => $yesno,
+					'pop3' => $pop3,
+					'imap' => $imap,
+					'customerid' => $customerid,
+					'domainid' => $id
+				]);
+
+				$this->logger()->logAction(FroxlorLogger::ADM_ACTION, LOG_NOTICE, "[API] " . ($deactivated ? 'deactivated' : 'reactivated') . " domain '" . $result['domain'] . "'");
+				Cronjob::inserttask(TaskId::REBUILD_VHOST);
+			}
+
 			$_update_data['customerid'] = $customerid;
 			$_update_data['adminid'] = $adminid;
 			$_update_data['phpenabled'] = $phpenabled;
@@ -1921,6 +1941,7 @@ class Domains extends ApiCommand implements ResourceEntity
 			$_update_data['honorcipherorder'] = $honorcipherorder;
 			$_update_data['sessiontickets'] = $sessiontickets;
 			$_update_data['parentdomainid'] = $id;
+			$_update_data['deactivated'] = $deactivated;
 
 			// if php config is to be set for all subdomains, check here
 			$update_phpconfig = '';
@@ -1953,7 +1974,8 @@ class Domains extends ApiCommand implements ResourceEntity
 				`ssl_cipher_list` = :ssl_cipher_list,
 				`tlsv13_cipher_list` = :tlsv13_cipher_list,
 				`ssl_honorcipherorder` = :honorcipherorder,
-				`ssl_sessiontickets` = :sessiontickets
+				`ssl_sessiontickets` = :sessiontickets,
+				`deactivated` = :deactivated
 				" . $update_phpconfig . $upd_specialsettings . $updatechildren . $update_sslredirect . "
 				WHERE `parentdomainid` = :parentdomainid
 			");
@@ -2073,9 +2095,6 @@ class Domains extends ApiCommand implements ResourceEntity
 	 *            optional, the domain-id
 	 * @param string $domainname
 	 *            optional, the domainname
-	 * @param bool $delete_mainsubdomains
-	 *            optional, remove also domains that are subdomains of this domain but added as main domains; default
-	 *            false
 	 * @param bool $is_stdsubdomain
 	 *            optional, default false, specify whether it's a std-subdomain you are deleting as it does not count
 	 *            as subdomain-resource
@@ -2091,7 +2110,6 @@ class Domains extends ApiCommand implements ResourceEntity
 			$dn_optional = $id > 0;
 			$domainname = $this->getParam('domainname', $dn_optional, '');
 			$is_stdsubdomain = $this->getParam('is_stdsubdomain', true, 0);
-			$remove_subbutmain_domains = $this->getParam('delete_mainsubdomains', true, 0);
 
 			$result = $this->apiCall('Domains.get', [
 				'id' => $id,
@@ -2099,15 +2117,10 @@ class Domains extends ApiCommand implements ResourceEntity
 			]);
 			$id = $result['id'];
 
-			// check for deletion of main-domains which are logically subdomains, #329
-			$rsd_sql = '';
-			if ($remove_subbutmain_domains) {
-				$rsd_sql .= " OR `ismainbutsubto` = :id";
-			}
-
 			$subresult_stmt = Database::prepare("
-					SELECT `id` FROM `" . TABLE_PANEL_DOMAINS . "`
-					WHERE (`id` = :id OR `parentdomainid` = :id " . $rsd_sql . ")");
+				SELECT `id` FROM `" . TABLE_PANEL_DOMAINS . "`
+				WHERE (`id` = :id OR `parentdomainid` = :id)
+			");
 			Database::pexecute($subresult_stmt, [
 				'id' => $id
 			], true, true);
@@ -2129,23 +2142,10 @@ class Domains extends ApiCommand implements ResourceEntity
 				$this->logger()->logAction(FroxlorLogger::ADM_ACTION, LOG_NOTICE, "[API] deleted domain/s from mail-tables");
 			}
 
-			// if mainbutsubto-domains are not to be deleted, re-assign the (ismainbutsubto value of the main
-			// domain which is being deleted) as their new ismainbutsubto value
-			if ($remove_subbutmain_domains !== 1) {
-				$upd_stmt = Database::prepare("
-						UPDATE `" . TABLE_PANEL_DOMAINS . "` SET
-						`ismainbutsubto` = :newIsMainButSubtoValue
-						WHERE `ismainbutsubto` = :deletedMainDomainId
-						");
-				Database::pexecute($upd_stmt, [
-					'newIsMainButSubtoValue' => $result['ismainbutsubto'],
-					'deletedMainDomainId' => $id
-				], true, true);
-			}
-
 			$del_stmt = Database::prepare("
-					DELETE FROM `" . TABLE_PANEL_DOMAINS . "`
-					WHERE `id` = :id OR `parentdomainid` = :id " . $rsd_sql);
+				DELETE FROM `" . TABLE_PANEL_DOMAINS . "`
+				WHERE `id` = :id OR `parentdomainid` = :id
+			");
 			Database::pexecute($del_stmt, [
 				'id' => $id
 			], true, true);
@@ -2230,4 +2230,118 @@ class Domains extends ApiCommand implements ResourceEntity
 		}
 		throw new Exception("Not allowed to execute given command.", 403);
 	}
+
+	/**
+	 * duplicate domain entry by either id or domainname. All parameters from Domains.add() can be used
+	 * to overwrite source entity values if necessary.
+	 *
+	 * @param int $id
+	 *            optional, the domain-id
+	 * @param string $domainname
+	 *            optional, the domainname
+	 * @param string $domain
+	 *            required, name of the new domain to be added
+	 *
+	 * @access admin
+	 * @return string json-encoded array
+	 * @throws Exception
+	 */
+	public function duplicate()
+	{
+		if ($this->isAdmin()) {
+			// parameters
+			$id = $this->getParam('id', true, 0);
+			$dn_optional = $id > 0;
+			$domainname = $this->getParam('domainname', $dn_optional, '');
+			$p_domain = $this->getParam('domain');
+
+			// get requested domain
+			$result = $this->apiCall('Domains.get', [
+				'id' => $id,
+				'domainname' => $domainname,
+			]);
+
+			// clear some defaults
+			unset($result['domain_ace']);
+			unset($result['adminid']);
+			unset($result['documentroot']);
+			unset($result['registration_date']);
+			unset($result['termination_date']);
+			unset($result['zonefile']);
+			// clear auto-generated values
+			unset($result['bindserial']);
+			unset($result['dkim_privkey']);
+			unset($result['dkim_pubkey']);
+			// clear api-call generated fields
+			unset($result['domain_hascert']);
+
+			// set correct ip/port information
+			$domain_ips = $result['ipsandports'];
+			unset($result['ipsandports']);
+			$result['ipandport'] = [];
+			$result['ssl_ipandport'] = [];
+			foreach ($domain_ips as $dip) {
+				if ($dip['ssl'] == 1) {
+					$result['ssl_ipandport'][] = $dip['id'];
+				} else {
+					$result['ipandport'][] = $dip['id'];
+				}
+			}
+
+			// check whether we are changing the customer/owner
+			if ($this->getParam('customerid', true, 0) == 0 && $this->getParam('loginname', true, '') == '') {
+				$customerid = $result['customerid'];
+			} else {
+				$customer = $this->getCustomerData();
+				$customerid = $customer['customerid'];
+			}
+
+			// check for alias-domain and whether it belongs to the target user
+			if (!empty($result['aliasdomain']) && $customerid == $result['customerid']) {
+				// duplicate alias entry
+				$result['alias'] = $result['aliasdomain'];
+			}
+			unset($result['aliasdomain']);
+
+			// validate possible fpm configs and whether the customer is allowed to use them
+			if ($customerid != $result['customerid']) {
+				$allowed_phpconfigs = json_decode($customer['allowed_phpconfigs'] ?? '[]', true);
+				if (empty($allowed_phpconfigs)) {
+					// system defaults
+					unset($result['phpsettingid']);
+				} elseif (!in_array($result['phpsettingid'], $allowed_phpconfigs)) {
+					// use the first customer allowed config
+					$result['phpsettingid'] = array_shift($allowed_phpconfigs);
+				}
+			}
+
+			// translate serveralias values
+			$result['selectserveralias'] = 2;
+			if ((int)$result['wwwserveralias'] == 1) {
+				$result['selectserveralias'] = 1;
+			} elseif ((int)$result['iswildcarddomain'] == 1) {
+				$result['selectserveralias'] = 0;
+			}
+			unset($result['wwwserveralias']);
+			unset($result['iswildcarddomain']);
+
+			// translate sslenabled flag
+			$result['sslenabled'] = $result['ssl_enabled'];
+			unset($result['ssl_enabled']);
+
+			$additional_params = $this->getParamList();
+			// unset unneeded params from this call
+			unset($additional_params['id']);
+			unset($additional_params['domainname']);
+			unset($additional_params['domain']);
+
+			// set new values and merge with optional add() parameters
+			$new_domain = array_merge($result, $additional_params);
+			$new_domain['domain'] = $p_domain;
+
+			$result_new = $this->apiCall('Domains.add', $new_domain);
+			return $this->response($result_new);
+		}
+		throw new Exception("Not allowed to execute given command.", 403);
+	}
 }
